@@ -5,7 +5,7 @@ import enum
 from datetime import datetime, date, timedelta
 from dataclasses import dataclass
 
-from .exceptions import EnumParseError
+from . import exceptions
 
 
 @enum.unique
@@ -76,13 +76,16 @@ class DataType(enum.Enum):
     DUAL_GAMMA = (184, True)
 
     # OHLC
-    OPEN = (191, False)
-    HIGH = (192, False)
-    LOW = (193, False)
-    CLOSE = (194, False)
+    OPEN = (191, True)
+    HIGH = (192, True)
+    LOW = (193, True)
+    CLOSE = (194, True)
 
     # IMPLIED VOLATILITY
-    IMPLIED_VOL = (201, False)
+    IMPLIED_VOL = (201, True)
+    BID_IMPLIED_VOL = (202, True)
+    ASK_IMPLIED_VOL = (203, True)
+    UNDERLYING_PRICE = (204, True)
 
     # OTHER
     RATIO = (211, True)
@@ -105,7 +108,7 @@ class DataType(enum.Enum):
         for member in cls:
             if code == member.value[0]:
                 return member
-        raise EnumParseError(code, cls)
+        raise exceptions._EnumParseError(code, cls)
 
     def code(self) -> int:
         """:return: The datatype code associated w this type."""
@@ -164,7 +167,7 @@ class MessageType(enum.Enum):
         for member in cls:
             if code == member.value:
                 return member
-        raise EnumParseError(code, cls)
+        raise exceptions._EnumParseError(code, cls)
 
 
 @enum.unique
